#
# spec file for package shibboleth-sp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global _tmpfilesdir %{_libexecdir}/tmpfiles.d
# tmpfiles_create macro doesn't exist for openSUSE:Leap:42.1
%if %{undefined tmpfiles_create}
  %define tmpfiles_create() \
  %{_bindir}/systemd-tmpfiles --create %{?*} || : \
  %{nil}
%endif
%define runuser shibd
%define realname shibboleth
%define pkgdocdir %{_docdir}/%{realname}
Name:           shibboleth-sp
Version:        2.6.1
Release:        lp151.3.3.1
Summary:        Open source system for attribute-based Web SSO
License:        Apache-2.0
Group:          Productivity/Networking/Security
Url:            http://shibboleth.net/
Source0:        http://shibboleth.net/downloads/service-provider/%{version}/%{name}-%{version}.tar.bz2
Source1:        http://shibboleth.net/downloads/service-provider/%{version}/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Source3:        shibd.service
Patch0:         shibboleth-sp-2.5.5-doxygen_timestamp.patch
Patch1:         shibboleth-sp-2.5.6-libsystemd-daemon.patch
BuildRequires:  apache2-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  krb5-devel
BuildRequires:  liblog4shib-devel >= 1.0.4
BuildRequires:  libmemcached-devel
BuildRequires:  libsaml-devel >= 2.6.0
BuildRequires:  libtool
BuildRequires:  libxerces-c-devel >= 3.1
BuildRequires:  libxml-security-c-devel >= 1.7.3
BuildRequires:  libxmltooling-devel >= 1.6.0
BuildRequires:  pkgconfig
BuildRequires:  systemd-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  unixODBC-devel
BuildRequires:  zlib-devel
Requires:       openssl
PreReq:         opensaml-schemas >= 2.6.0
PreReq:         xmltooling-schemas >= 1.6.0
Requires(pre):  pwdutils
Obsoletes:      shibboleth-sp = 2.5.0
%{?systemd_requires}
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel >= 1.32.0
%endif

%description
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package contains the Shibboleth Service Provider runtime libraries,
daemon, default plugins, and Apache module.

%package -n libshibsp7
Summary:        Shared Library for Shibboleth
Group:          Productivity/Networking/Security

%description -n libshibsp7
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package contains just the shared library.

%package -n libshibsp-lite7
Summary:        Shared Library for Shibboleth
Group:          Productivity/Networking/Security

%description -n libshibsp-lite7
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package contains just the shared library.

%package devel
Summary:        Shibboleth Development Headers
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Requires:       liblog4shib-devel >= 1.0.4
Requires:       libsaml-devel >= 2.6.0
Requires:       libshibsp-lite7 = %{version}-%{release}
Requires:       libshibsp7 = %{version}-%{release}
Requires:       libxerces-c-devel >= 3.1
Requires:       libxml-security-c-devel >= 1.7.3
Requires:       libxmltooling-devel >= 1.6.0
Obsoletes:      shibboleth-sp-devel = 2.5.0

%description devel
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package includes files needed for development with Shibboleth.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
export CXXFLAGS="%{optflags} --std=c++11"
autoreconf -f -i
%configure --with-gssapi --enable-systemd --with-memcached
make %{?_smp_mflags} pkgdocdir=%{pkgdocdir}

%install
make install NOKEYGEN=1 DESTDIR=%{buildroot} pkgdocdir=%{pkgdocdir}

install -D -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/shibd.service
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rcshibd

sed -i "s/\/var\/log\/httpd/\/var\/log\/apache2/g" \
		%{buildroot}%{_sysconfdir}/%{realname}/native.logger

# Delete unnecessary files
pushd %{buildroot}/%{_sysconfdir}/%{realname}
rm shibd-debian shibd-redhat shibd-amazon shibd-suse shibd-osx.plist apache.config apache2.config apache22.config shibd-systemd
rm *.dist
popd

# Plug the SP into the Apache
touch rpm.filelist
APACHE_CONFIG="no"
if [ -f %{buildroot}%{_libdir}/%{realname}/mod_shib_24.so ] ; then
	APACHE_CONFIG="apache24.config"
fi

if [ "$APACHE_CONFIG" != "no" ] ; then
	APACHE_CONFD="no"
	if [ -d %{_sysconfdir}/apache2/conf.d ] ; then
		APACHE_CONFD="%{_sysconfdir}/apache2/conf.d"
	fi
	if [ "$APACHE_CONFD" != "no" ] ; then
		mkdir -p $RPM_BUILD_ROOT$APACHE_CONFD
		cp -p %{buildroot}%{_sysconfdir}/%{realname}/$APACHE_CONFIG $RPM_BUILD_ROOT$APACHE_CONFD/shib.conf
		echo "%config(noreplace) $APACHE_CONFD/shib.conf" >> rpm.filelist
	fi
fi

# Get run directory created at boot time.
mkdir -p %{buildroot}%{_tmpfilesdir}
echo "%attr(0444,-,-) %{_tmpfilesdir}/%{realname}.conf" >> rpm.filelist
cat > %{buildroot}%{_tmpfilesdir}/%{realname}.conf <<EOF
d /run/%{realname} 755 %{runuser} %{runuser} -
EOF

%check
make %{?_smp_mflags} check

%pre
getent group %{runuser} >/dev/null || groupadd -r %{runuser}
getent passwd %{runuser} >/dev/null || useradd -r -g %{runuser} \
	-d  %{_localstatedir}/run/%{realname} -s /sbin/nologin -c "Shibboleth SP daemon" %{runuser}
%service_add_pre shibd.service
exit 0

%post -n libshibsp7 -p /sbin/ldconfig
%post -n libshibsp-lite7 -p /sbin/ldconfig
%post
# Key generation
cd %{_sysconfdir}/%{realname}
if [ ! -f sp-key.pem ] ; then
	/bin/sh ./keygen.sh -b -u %{runuser} -g %{runuser}
fi

%service_add_post shibd.service

%tmpfiles_create %{_tmpfilesdir}/%{realname}.conf

%preun
# On final removal, stop shibd and remove service, restart Apache if running.
%service_del_preun shibd.service
if [ $1 -eq 0 ] ; then
	/sbin/service apache2 status 1>/dev/null && /sbin/service apache2 restart 1>/dev/null
fi
exit 0

%postun -n libshibsp7 -p /sbin/ldconfig
%postun -n libshibsp-lite7 -p /sbin/ldconfig
%postun
%service_del_postun shibd.service
%restart_on_update apache2

%posttrans
# One-time extra restart of shibd and Apache to work around
# SUSE bug that breaks old %%restart_on_update macro.
# If we remove, upgrades from pre-systemd to post-systemd
# will stop doing the final restart.
%{_bindir}/systemctl try-restart shibd >/dev/null 2>&1 || :
%{_bindir}/systemctl try-restart apache2 >/dev/null 2>&1 || :
exit 0

%files -f rpm.filelist
%{_sbindir}/shibd
%{_sbindir}/rcshibd
%{_bindir}/mdquery
%{_bindir}/resolvertest
%dir %{_libdir}/%{realname}
%{_libdir}/%{realname}/*
%{_unitdir}/shibd.service
%attr(0750,%{runuser},%{runuser}) %dir %{_localstatedir}/log/%{realname}
%attr(0750,wwwrun,www) %dir %{_localstatedir}/log/%{realname}-www
%attr(0755,%{runuser},%{runuser}) %dir %{_localstatedir}/cache/%{realname}
%ghost %attr(0755,%{runuser},%{runuser}) %dir /run/%{realname}
%dir %{_datadir}/xml/%{realname}
%{_datadir}/xml/%{realname}/*
%dir %{_datadir}/%{realname}
%{_datadir}/%{realname}/*
%dir %{_sysconfdir}/%{realname}
%config(noreplace) %{_sysconfdir}/%{realname}/*.xml
%config(noreplace) %{_sysconfdir}/%{realname}/*.html
%config(noreplace) %{_sysconfdir}/%{realname}/*.logger
%{_tmpfilesdir}/%{realname}.conf
%{_sysconfdir}/%{realname}/apache24.config
%attr(0755,root,root) %{_sysconfdir}/%{realname}/keygen.sh
%attr(0755,root,root) %{_sysconfdir}/%{realname}/metagen.sh
%doc %{pkgdocdir}
%exclude %{pkgdocdir}/api

%files -n libshibsp7
%{_libdir}/libshibsp.so.*

%files -n libshibsp-lite7
%{_libdir}/libshibsp-lite.so.*

%files devel
%{_includedir}/*
%{_libdir}/libshibsp.so
%{_libdir}/libshibsp-lite.so
%doc %{pkgdocdir}/api

%changelog
* Mon Dec  2 2019 Kristyna Streitova <kstreitova@suse.com>
- remove fixing of the ownership of log files and the key as this
  allows shibd to escalate to root [bsc#1157471] [CVE-2019-19191]
* Wed Nov 15 2017 kstreitova@suse.com
- update to 2.6.1
  * list of fixes and enhancements
    https://issues.shibboleth.net/jira/browse/SSPCPP-760?filter=12270
  * fixes [bsc#1068689] [CVE-2017-16852]
* Thu Sep 21 2017 kstreitova@suse.com
- update to 2.6.0
  * list of fixes and enhancements
    https://issues.shibboleth.net/jira/browse/SSPCPP-716?filter=11475
- update soname for libshibsp from 6 to 7
- adjust BuildRequires of boost
  * libboost_headers-devel for openSUSE:Factory
  * boost-devel for older distros
- update versions of BuildRequires for opensaml (>= 2.6.0) and
  libxmltooling (>= 1.6.0)
- shibd.service: increase TimeoutStartSec to 150s (as upstream did)
- remove %%{_sysconfdir}/%%{realname}/*.xsl from filelist (it is no
  longer present)
- run spec-cleaner
* Thu Mar 16 2017 kstreitova@suse.com
- fix build for openSUSE:Leap:42.1 by adding %%define for
  tmpfiles_create as this macro doesn't exist there
* Tue Feb 14 2017 kstreitova@suse.com
- add shibboleth-sp-2.5.6-libsystemd-daemon.patch to fix configure
  to use libsystemd instead of obsolete libsystemd-daemon.
  Regenerate configure via autoreconf and add autoconf and automake
  BuildRequires.
* Tue Jul 19 2016 dimstar@opensuse.org
- Use %%tmpfiles_create macro: gracefully fails in case of missing
  binaries (e.g. container setups).
* Wed May 11 2016 kstreitova@suse.com
- build libmemcached support
* Fri Apr  8 2016 kstreitova@suse.com
- update to shibboleth-sp 2.5.6
  * Update solution file after loading into VS2015
  * SSPCPP-669 - cached samlds.json files prematurely removed w/ multiple
  * applicationIds
  * SSPCPP-671 - Handling of partial success in LogoutResponse needs work
  * Fix line feeds again, VS is also broken
  * SSPCPP-670 - Session Cleanup for Database Session Storage can cause performance issues
  * Re-convert linefeeds to undo Eclipse's handiwork
  * SSPCPP-675 - configuration sample cites "federation.org"
  * Clean up ignores
  * Apply typo fixes provided by Debian packagers
  * Update library/software version
  * Update MSI names to carry patch version
  * SSPCPP-665 - Use of systemd breaks on reboot
* Wed Aug  5 2015 mpluskal@suse.com
- Add gpg signature
* Thu Jul 30 2015 kstreitova@suse.com
- fix some warnings
- add service as a separate file
- remove command line switches for conditional package builds
- remove *.dist files and unused *.config files
- remove unused conditionals
- move libraries to the subpackages
* Mon Jul 27 2015 kstreitova@suse.com
- use spec-cleaner
- package cleaning
- add shibboleth-sp-2.5.5-doxygen_timestamp.patch to remove
  timestamps in a documentation generated by Doxygen and avoid
  RPMLINT warnings (file-contains-date-and-time).
- add the macro %%{realname} and change a name to "shibboleth-sp"
- fix Source address
* Fri Jul 24 2015 kstreitova@suse.com
- initial revision
